/**
 * Copyright 2008,2009,2010,2011 Charles Amey
 * 
 * This file is part of Fuel Manager.
 * 
 * Fuel Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Fuel Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Fuel Manager.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <QColor>
#include <QDebug>
#include "monthmodel.h"

//constructor
MonthModel::MonthModel(QObject *parent)
	: QAbstractTableModel(parent)
{
	dataItems.clear();
	colors.clear();
	verticalHeaders.clear();
	horizontalHeaders.clear();
}//end constructor

//destructor
MonthModel::~MonthModel()
{
}

void MonthModel::setModelData (QList < QVariant > d, QList< QColor > c)
{
     //dataItems.prepend(d);
	dataItems.append(d);
     colors.prepend(c);
}


//returns the number of rows in the model
int MonthModel::rowCount(const QModelIndex &index) const
{
	if (index.isValid())
		return 0;
	return dataItems.size();
}

//returns the number of columns in the model
int MonthModel::columnCount(const QModelIndex &index) const
{
	if (index.isValid())
		return 0;
	QList <QVariant> t = dataItems.at(0);
	return t.size();
}

QVariant MonthModel::data(const QModelIndex &index,int role) const
{
	if (index.isValid())
	{
		if (role == Qt::DisplayRole)
		{
			QList <QVariant> t = dataItems.at(index.row());
			QVariant u = t.at(index.column());
/*			if (index.column() == 4)
			{
				QString c = "$";
				QString m;
				m.setNum(u.toDouble(), 'f',2);
				c = c + m;
				return c;
			}
			if (index.column() == 5)
			{
				double mpg = u.toDouble();
				QString m;
				m.setNum(mpg, 'f',3);
				return m;
			}*/
			return u.toString();
		}
		if (role == Qt::BackgroundColorRole)
		{
			QList <QColor> row = colors.at(index.row());
			QColor c = row.at(index.column());
			return c;
		}
/*		if (role == Qt::EditRole)
		{
			QList <QVariant> t = dataItems.at(index.row());
			QVariant u = t.at(index.column());
			return u;
		}*/
	}
	return QVariant();
}//end data


//get the headers
QVariant MonthModel::headerData(int section, Qt::Orientation orientation,int role) const
{
	//Qt::Horizontal 1
	//Qt::Vertical 2
	if (orientation == Qt::Vertical)
	{
		if (role == Qt::DisplayRole)
		{
			if (section < verticalHeaders.size())
				return verticalHeaders.at(section);
		}
	}
	else if (orientation == Qt::Horizontal)
	{
		if (role == Qt::DisplayRole)
		{
			if (section < horizontalHeaders.size())
				return horizontalHeaders.at(section);
		}
	}
	return QAbstractTableModel::headerData(section, orientation, role);
}//end headerData

//set up the headers
bool MonthModel::setHeaderData ( int section, Qt::Orientation orientation, const QVariant & value, int role)
{
	bool ok = false;
	if (orientation == Qt::Vertical)
	{
		if (role == Qt::DisplayRole)
		{
			verticalHeaders.insert(section,value);
			ok = true;
		}
	}
	if (orientation == Qt::Horizontal)
	{
		if (role == Qt::DisplayRole)
		{
			horizontalHeaders.insert(section,value);
			ok = true;
		}
	}
	return ok;
}//end setHeaderData

void MonthModel::clearEverything()
{
	dataItems.clear();
	colors.clear();
	verticalHeaders.clear();
	horizontalHeaders.clear();
}//end clearEverything


// 		Qt::ItemFlags flags(const QModelIndex &index) const;
// 
// 		bool setData(const QModelIndex &index, const QVariant &value, int role=Qt::EditRole);
// 		
// 		
// 		QList <QVariant> getRow (int rowIndex);
// 		int getSize();
// 		int getSizeColors();
// 		void clear();

		
